Documentation
=============

Training Data Retrieval
-----------------------

Module `shorttext.data.data_retrieval`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.data.data_retrieval
   :members:

Text Preprocessing
------------------

Module `shorttext.utils.textpreprocessing`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.utils.textpreprocessing
   :members:

Topic Models
------------

Module `shorttext.generators.bow.LatentTopicModeling`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.generators.bow.LatentTopicModeling
   :members:

Module `shorttext.generators.bow.GensimTopicModeling`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.generators.bow.GensimTopicModeling
   :members:

Module `shorttext.generators.bow.AutoEncodingTopicModeling`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.generators.bow.AutoEncodingTopicModeling
   :members:


Module `shorttext.classifiers.topic.TopicVectorDistanceClassification`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.bow.topic.TopicVectorDistanceClassification
   :members:

Module `shorttext.classifiers.topic.SkLearnClassification`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.bow.topic.SkLearnClassification
   :members:

Supervised Classification using Word Embedding
----------------------------------------------

Module `shorttext.classifiers.embed.sumvec.SumEmbedVecClassification`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.embed.sumvec.SumEmbedVecClassification
   :members:

Module `shorttext.classifiers.embed.sumvec.VarNNSumEmbedVecClassification`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.embed.sumvec.VarNNSumEmbedVecClassification
   :members:

Module `shorttext.classifiers.embed.nnlib.VarNNEmbedVecClassification`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.embed.nnlib.VarNNEmbedVecClassification
   :members:

Maximum Entropy Classifiers
---------------------------

Module `shorttext.classifiers.bow.maxent.MaxEntClassification`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.bow.maxent.MaxEntClassification
   :members:

Neural Networks
---------------

Module `shorttext.classifiers.embed.sumvec.frameworks`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.embed.sumvec.frameworks
   :members:

Module `shorttext.classifiers.embed.nnlib.frameworks`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.classifiers.embed.nnlib.frameworks
   :members:

Utilities
---------

Module `shorttext.utils.kerasmodel_io`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.utils.kerasmodel_io
   :members:

Module `shorttext.utils.gensim_corpora`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.utils.gensim_corpora
   :members:

Module `shorttext.utils.wordembed`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.utils.wordembed
   :members:

Module `shorttext.utils.compactmodel_io`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.utils.compactmodel_io
   :members:

Stacked Generalization
----------------------

Module `shorttext.stack`
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.stack.stacking
   :members:

Metrics
-------

Module `shorttext.metrics.dynprog`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.metrics.dynprog.dldist
   :members:

.. automodule:: shorttext.metrics.dynprog.jaccard
   :members:

Module `shorttext.metrics.wassersterin`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.metrics.wasserstein.wordmoverdist
   :members:

Spell Correction
----------------

Module `shorttext.spell`
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: shorttext.spell.basespellcorrector
   :members:

.. automodule:: shorttext.spell.norvig
   :members:

.. automodule:: shorttext.spell.sakaguchi
   :members:




Home: :doc:`index`